#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 postgrest
version:              10.1.0
visibility:           public
id:                   postgrest-10.1.0-LMATPlmjq7CDoSDPnKHKFf
key:                  postgrest-10.1.0-LMATPlmjq7CDoSDPnKHKFf
license:              MIT
maintainer:           Steve Chavez <stevechavezast@gmail.com>
author:               Joe Nelson, Adam Baker, Steve Chavez
homepage:             https://postgrest.org
synopsis:             REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for tables, views, and functions, supporting all HTTP methods that security
    permits.

category:             Executable, PostgreSQL, Network APIs
abi:                  5a51fe034bba97dd693e226e80deb62d
exposed:              True
exposed-modules:
    PostgREST.ApiRequest PostgREST.ApiRequest.Preferences
    PostgREST.ApiRequest.QueryParams PostgREST.ApiRequest.Types
    PostgREST.App PostgREST.AppState PostgREST.Auth PostgREST.CLI
    PostgREST.Config PostgREST.Config.Database PostgREST.Config.JSPath
    PostgREST.Config.PgVersion PostgREST.Config.Proxy PostgREST.Cors
    PostgREST.Error PostgREST.Logger PostgREST.MediaType PostgREST.Plan
    PostgREST.Plan.CallPlan PostgREST.Plan.MutatePlan
    PostgREST.Plan.ReadPlan PostgREST.Query
    PostgREST.Query.QueryBuilder PostgREST.Query.SqlFragment
    PostgREST.Query.Statements PostgREST.RangeQuery PostgREST.Response
    PostgREST.Response.GucHeader PostgREST.Response.OpenAPI
    PostgREST.SchemaCache PostgREST.SchemaCache.Identifiers
    PostgREST.SchemaCache.Proc PostgREST.SchemaCache.Relationship
    PostgREST.SchemaCache.Table PostgREST.Unix PostgREST.Version
    PostgREST.Workers

hidden-modules:       Paths_postgrest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/postgrest-10.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/postgrest
hs-libraries:         HSpostgrest-10.1.0-LMATPlmjq7CDoSDPnKHKFf
depends:
    HTTP-4000.5.0-BGsyAMO7h689eMWOIdU6y2
    Ranged-sets-0.5.0-KTwzwxpicuJLneRK5J5pvm
    aeson-2.2.2.0-EwrTYsTfELe3d4orbILmv4
    auto-update-0.1.6-LpZrL5YcA2Q53gAvj8DEM0 base-4.18.2.1
    base64-bytestring-1.2.1.0-C0qMqvh3vbu1LTlZEUtx0r
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-CbvbZydH4uCGBf3Bqda73d
    cassava-0.5.4.1-8mn67l2kKnrJog4yM9jD01
    configurator-pg-0.2.11-E2DuSNvswgfKjCb8vFpSXX containers-0.6.7
    contravariant-extras-0.3.5.4-Jp1EzHgD0E5KQ707vKnuxI
    cookie-0.5.0-Dqi2dsQ09KG8Z0mbWITxu5 directory-1.3.8.5
    either-5.0.3-Bojc9KWorLbE0ypaHhmU7h
    gitrev-1.3.1-HjgHeGOzFY1JvYhlt8eDSs
    hasql-1.6.1.1-IQ5e7wLDaSLCwS4iLxZBPz
    hasql-dynamic-statements-0.3.1.2-Ihejo2SACytmW8OyitbMD
    hasql-notifications-0.2.0.6-7nlBhw8CkA5HT9IStX0yhW
    hasql-pool-0.8.0.3-GyicND3ro3y6VbRyMQkgVy
    hasql-transaction-1.0.1.3-BdTR9nBe4QNG6so1lqQvYb
    heredoc-0.2.0.0-6fzsisYvDUd6tBbd4jIzIt
    http-types-0.12.4-D4ln0jiwEOhAKcR3fqSchY
    insert-ordered-containers-0.2.5.3-8hZZdfB78Z0GGkxJIY3244
    interpolatedstring-perl6-1.0.2-HBRdXfKUL6b2IYdQ3Y0028
    jose-0.10.0.1-KTJIbmtUOpyFQuhsVHC7yi
    lens-5.3.5-7MUa280kiW5NfytVlUfpR
    lens-aeson-1.2.3-7JJzUPZSqgKKkB98t4Blwl mtl-2.3.1
    network-3.1.4.0-946StwFfSrELqUahTPYWqr
    network-uri-2.6.4.2-HyBVnFdXLs0Dgiq4qkHmFH
    optparse-applicative-0.18.1.0-2OPlFtvlr5yI8qFRB5F8bn
    parsec-3.1.16.1 protolude-0.3.5-yvDFW6A2ig6xC7LiLK78G
    regex-tdfa-1.3.2.5-5Xsa8Nkm5ozG5wMRmCPABC
    retry-0.9.3.1-2yeM0AgITxv5jkUTX6ziOD
    scientific-0.3.8.1-8GGUGhnyv3iL0QkuRDa0Ak
    swagger2-2.9-Arx8IlRURRmHQGins7C2lS text-2.0.2 time-1.12.2
    unix-2.8.4.0 unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z
    vault-0.3.1.6-48aEcoRm4UuGzuAzBRA8v7
    vector-0.13.2.0-pkGAkHyCfVA94J1hIBHJi
    wai-3.2.4-HOJRNxSLXyTJ5Lq7jmcw5j
    wai-cors-0.2.7-BYhZU0mGlnUBrWwCBBIomK
    wai-extra-3.1.18-HZccfn8lStF2qIDmQsBXmA
    wai-logger-2.5.0-7jaK26jiMc12IMOSSvGTfU
    warp-3.4.0-KIEmCyfVmmO5GM68R2rzXC

haddock-interfaces:   /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html:         /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

